# Syngas from Methane

This is a process synthesis model for the production of syngas from methane.

Source paper (Chapter 8):

> Qi Chen. Pyosyn: Advanced Computational Tools for Process Synthesis. PhD thesis. May 2020. Carnegie Mellon University, Department of Chemical Engineering.

Adapted from:

> Medrano-García, J. D., Ruiz-Femenia, R., & Caballero, J. A. (2017). Multi-objective optimization of combined synthesis gas reforming technologies. *Journal of CO2 Utilization*, 22(November), 355–373. https://doi.org/10.1016/j.jcou.2017.09.019

## Problem Details

### Solution

Optimal objective value: 4669

Environmental objective at solution point: -5354.8

### Size

| Problem   | vars | Bool | bin | int | cont | cons | nl | disj | disjtn |
|-----------|------|------|-----|-----|------|------|----|------|--------|
| syngas | 362 | 46 | 0 | 0 | 316 | 554 | 48 | 46 | 23 |

- ``vars``: variables
- ``Bool``: Boolean variables
- ``bin``: binary variables
- ``int``: integer variables
- ``cont``: continuous variables
- ``cons``: constraints
- ``nl``: nonlinear constraints
- ``disj``: disjuncts
- ``disjtn``: disjunctions
